# Reinforcement Learning Environments for Yahtzee
This repo contains all of the source code for a basic environment to support training various RL agents to maximize their score in a game of Yahtzee. It is built on top of the Yahtzee API whose docs are found at https://yahtzee-api.tomarbeiter.com. 

Currently there are 2 environments for a single player game of Yahtzee (the first one is bad and should not be used). Full documentation for the environments can be found at https://yahtzee-envs.tomarbeiter.com. It is modeled after the OpenAI framework, but is not fully compatible with the standard. 

### Installation
To install this package, run `pip install yahtzee-envs`

### Contributing
For quesitons, comments, or to contribute your own environment reach out to me via email: arbeitertom@gmail.com. 